@@ -1,21 +1,3 @@
-/*
- * chamkho - a word breaker written in Rust
- * Copyright (C) 2015  Vee Satayamas
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
 #[macro_use]
 extern crate clap;
 
@@ -34,6 +16,8 @@ fn main() {
         Some(_dict_path) => Path::new(_dict_path),
         None => match lang {
             Some("lao") => lib::lao_path(),
+            Some("khmer") => lib::khmer_dict_path(),
+            Some("myanmar") => lib::myanmar_dict_path(),
             Some("thai") | Some(_) | None => lib::default_path(),
         },
     };
@@ -45,6 +29,8 @@ fn main() {
 
     let cluster_rule_path = match lang {
         Some("lao") => lib::lao_clusters_path(),
+        Some("khmer") => lib::khmer_clusters_path(),
+        Some("myanmar") => lib::myanmar_clusters_path(),
         Some("thai") | Some(_) | None => lib::thai_cluster_path(),
     };
 
@@ -59,13 +45,7 @@ fn main() {
 
     for line_opt in io::BufReader::new(io::stdin()).lines() {
         let cleaned_line = match line_opt {
-            Ok(line) => {
-                if line.len() > 0 {
-                    line.trim_end_matches('\n').to_string()
-                } else {
-                    line
-                }
-            }
+            Ok(line) => line.trim_end_matches('\n').to_string(),
             Err(e) => panic!("Cannot read line {}", e),
         };
 
